/*
 * Copyright (C) 2005 - 2015 by TESIS DYNAware GmbH
 */
package sample.presentation;

import javax.annotation.PreDestroy;
import javax.inject.Inject;
import javax.inject.Named;

import org.eclipse.e4.core.di.annotations.Optional;
import org.eclipse.e4.ui.services.IServiceConstants;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecp.ui.view.ECPRendererException;
import org.eclipse.emf.ecp.ui.view.swt.ECPSWTView;
import org.eclipse.emf.ecp.ui.view.swt.ECPSWTViewRenderer;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.widgets.Composite;

/**
 * Shows properties of an {@link EObject} in a form. Uses EMFForms to generate this form.
 */
public class PropertiesEditor {

    private ECPSWTView view;

    /**
     * Updates the form with the given selection if the selection contains an EObject as its first element.
     * @param selection the selection to be shown in the form
     * @param root the composite to which to attach the form view
     */
    @Inject
    @Optional
    public void update(@Named(IServiceConstants.ACTIVE_SELECTION) final Object selection, final Composite root) {
        if (selection instanceof IStructuredSelection) {

            final Object firstElement = ((IStructuredSelection) selection).getFirstElement();

            if (firstElement instanceof EObject) {
                try {
                    disposeFormView();
                    view = ECPSWTViewRenderer.INSTANCE.render(root, (EObject) firstElement);
                } catch (final ECPRendererException exception) {
                    exception.printStackTrace();
                }
            }
        }

    }

    @PreDestroy
    public void destroy() {
        disposeFormView();
    }
    private void disposeFormView() {
        if (view != null) {
            view.dispose();
        }
    }

}
