package oclemfforms.sampleapp.e3;

import java.net.URL;

import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.IPageLayout;
import org.eclipse.ui.IPerspectiveFactory;
import org.eclipse.ui.application.IWorkbenchConfigurer;
import org.eclipse.ui.application.IWorkbenchWindowConfigurer;
import org.eclipse.ui.application.WorkbenchAdvisor;
import org.eclipse.ui.application.WorkbenchWindowAdvisor;
import org.eclipse.ui.ide.IDE;
import org.eclipse.ui.internal.ide.IDEWorkbenchPlugin;
import org.osgi.framework.Bundle;

/**
 * This workbench advisor creates the window advisor, and specifies the perspective id for the initial window.
 */
public class ApplicationWorkbenchAdvisor extends WorkbenchAdvisor {

    @Override
    public WorkbenchWindowAdvisor createWorkbenchWindowAdvisor(final IWorkbenchWindowConfigurer configurer) {
        return new ApplicationWorkbenchWindowAdvisor(configurer);
    }

    @Override
    public String getInitialWindowPerspectiveId() {
        return Perspective.ID;
    }

    @Override
    public void initialize(final IWorkbenchConfigurer configurer) {
        super.initialize(configurer);

        // inserted: register workbench adapters
        IDE.registerAdapters();

        // inserted: register images for rendering explorer view
        final String ICONS_PATH = "icons/full/";
        final String PATH_OBJECT = ICONS_PATH + "obj16/";
        final Bundle ideBundle = Platform.getBundle(IDEWorkbenchPlugin.IDE_WORKBENCH);
        declareWorkbenchImage(configurer, ideBundle, IDE.SharedImages.IMG_OBJ_PROJECT, PATH_OBJECT + "prj_obj.gif",
                true);
        declareWorkbenchImage(configurer, ideBundle, IDE.SharedImages.IMG_OBJ_PROJECT_CLOSED, PATH_OBJECT
                + "cprj_obj.gif", true);
    }

    /**
     * Declares the image to be shown for the workbench.
     * @param configurer_p used to configure the workbench
     * @param ideBundle the ide's bundle
     * @param symbolicName the symbolic name of the image
     * @param path the image path
     * @param shared indicates if the image should be shared
     */
    private void declareWorkbenchImage(final IWorkbenchConfigurer configurer_p, final Bundle ideBundle,
            final String symbolicName, final String path, final boolean shared) {
        final URL url = ideBundle.getEntry(path);
        final ImageDescriptor desc = ImageDescriptor.createFromURL(url);
        configurer_p.declareImage(symbolicName, desc, shared);
    }

    /**
     * A default E3 perspective
     */
    private class Perspective implements IPerspectiveFactory {

        /**
         * The ID of the perspective as specified in the extension.
         */
        public static final String ID = "StiTestApp.perspective";

        @Override
        public void createInitialLayout(final IPageLayout layout) {

        }
    }

}
